@@ -1,5 +1,8 @@
 # photo1.pl
 
+use warnings;
+use strict;
+
 use vars qw/$TOP/;
 
 sub photo1 {
@@ -17,14 +20,15 @@ sub photo1 {
 
     my $f1 = $TOP->Photo( -file => Tcl::pTk->findINC( 'demos/images/teapot.ppm' ) );
     $l->configure( -image => $f1 );
-    $TOP->idletasks;
-    $TOP->after(2000);
-
-    foreach my $x ( 50 .. 100 ) {
-	foreach my $y ( 50 .. 100 ) {
-	    $f1->transparencySet( $x, $y, 1 );
-	    $f1->update;
-	}
-    }
+    $TOP->after(2000,
+        sub {
 
+            foreach my $x ( 50 .. 100 ) {
+            foreach my $y ( 50 .. 100 ) {
+                $f1->transparencySet( $x, $y, 1 );
+                $f1->update;
+            }
+            }
+        },
+    );
 } # end photo1
